package cn.sh.stc.sict.theme.hpgp.controller.mobile;


import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import cn.sh.stc.sict.cloud.common.core.util.R;
import cn.sh.stc.sict.cloud.common.security.util.SecurityUtils;
import cn.sh.stc.sict.cloud.upms.dto.CurrentUser;
import cn.sh.stc.sict.theme.hpgp.model.HpgpBusyIdlePrediction;
import cn.sh.stc.sict.theme.hpgp.service.HpHzjlService;
import cn.sh.stc.sict.theme.hphy.model.HpDocInfo;
import cn.sh.stc.sict.theme.hphy.model.HphyPatientBase;
import cn.sh.stc.sict.theme.hphy.service.HphyPatientBaseService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * (HpHzjl)表控制层
 *
 * @author F_xh
 * @since 2022-08-15 14:14:33
 */
@Slf4j
@RestController
@AllArgsConstructor
@Api(tags = "[C]患者就诊记录")
@RequestMapping("/hpHzjl")
public class HpHzjlController {
    /**
     * 服务对象
     */
    private final HpHzjlService hpHzjlService;
    private final HphyPatientBaseService hphyPatientBaseService;

    @ApiOperation("历史科室 list")
    @GetMapping("/history/dept/list")
    public R historyDeptList() {
        CurrentUser current = SecurityUtils.getCurrentUser();
        if (ObjectUtil.isEmpty(current) || StrUtil.isBlank(current.getOpenId())) {
            log.error("current = {}", JSONUtil.toJsonStr(current));
            return new R().error("当前的登录人信息异常");
        }
        HphyPatientBase patient = hphyPatientBaseService.getByOpenId(current.getOpenId());
        if (ObjectUtil.isEmpty(patient) || StrUtil.isBlank(patient.getCertId())) {
            log.error("patient = {}", JSONUtil.toJsonStr(patient));
            return new R().error("患者信息异常！");
        }
        List<HpgpBusyIdlePrediction> result = hpHzjlService.listByCertIdAndHosCode(patient.getCertId(), current.getHospitalCode());

        return new R(result);
    }

    @ApiOperation("历史医生 list")
    @GetMapping("/history/doctor/list")
    public R historyDoctorList() {
        CurrentUser current = SecurityUtils.getCurrentUser();
        if (ObjectUtil.isEmpty(current) || StrUtil.isBlank(current.getOpenId())) {
            log.error("current = {}", JSONUtil.toJsonStr(current));
            return new R().error("当前的登录人信息异常");
        }
        HphyPatientBase patient = hphyPatientBaseService.getByOpenId(current.getOpenId());
        if (ObjectUtil.isEmpty(patient) || StrUtil.isBlank(patient.getCertId())) {
            log.error("patient = {}", JSONUtil.toJsonStr(patient));
            return new R().error("患者信息异常！");
        }

        List<HpDocInfo> result = hpHzjlService.listDoctorByCertIdAndHosCode(patient.getCertId(), current.getHospitalCode());
        return new R(result);
    }
}
